---
title: Comment choisir un ERP responsable ?
description: Choisir un ERP responsable et être en conformité avec la loi de finance pour les petites et moyennes entreprises.
date: 2022-11-17
tags:
  - choix de solution
  - cadrage
  - open source
  - écoconception
authors:
  - Margaux Escande
layout: article.njk
---

Un ERP (Enterprise Resource Planning) est un progiciel de gestion intégré qui permet "de gérer l'ensemble des processus d'une entreprise en intégrant l'ensemble de ses fonctions, dont la gestion des ressources humaines, la gestion comptable et financière, l'aide à la décision, mais aussi la vente, la distribution, l'approvisionnement et le commerce électronique" [Wikipedia](https://fr.wikipedia.org/wiki/Progiciel_de_gestion_int%C3%A9gr%C3%A9)

## Les entreprises doivent s'outiller pour suivre l'évolution de la réglementation

[D'ici 2026, toutes les entreprises vont devoir émettre des factures électroniques à transmettre aux clients comme à l'administration fiscale.](https://www.legifrance.gouv.fr/jorf/id/JORFTEXT000044044176) Cela devrait permettre de lutter contre les fraudes, notamment à la TVA.

La date d'application varie en fonction de la taille de la structure : juillet 2024 pour les grandes entreprises, janvier 2025 pour les entreprises de tailles intermédiaires et janvier 2026 pour les PME et les microentreprises.

Les entreprises doivent donc s'outiller pour rendre cela possible. C'est dans ce contexte que nous avons rencontré Equip'tout.

Equip'tout est une société familiale créée en 2000, devenue une référence dans le Nord de la France dans le domaine de la [location de matériels](http://www.equiptout.fr/index.php?id_cms=1&controller=cms) pour les particuliers, les professionnels et les collectivités.

Equip'tout défend des valeurs environnementales et sociales qui nous ont amenées à travailler ensemble pour répondre aux nouvelles contraintes de dématérialisation de la facturation.

## La démarche pour choisir un ERP responsable

Avant toute chose, il est important que chaque partie prenante du projet et notamment les décisionnaires aient une bonne [compréhension des enjeux du numérique](https://www.itsonus.fr/enjeux_numerique/). C'est pourquoi nous avons commencé notre mission par une sensibilisation.

Puis, comme toute démarche projet, il convient d'explorer par des interviews et de l'observation le geste métier actuel. Cela nous a permis d’identifier les irritants et les points de satisfaction pour chercher la meilleure réponse.

Par exemple, nous avons appris qu'une partie du geste métier ne doit pas être numérisée pour s'assurer de la fluidité du
parcours. En effet, des fiches papiers sont utilisées dans le processus d'entretien des machines, ce qui donne de façon
rapide l'information du travail à réaliser sans manipuler un ordinateur.

![Fiches permettant de suivre l'entretien des machines](/blog_images/articles/comment_choisir_erp_responsable/image_1.jpg "Fiches permettant de suivre l'entretien des machines")

Après avoir pris connaissance de l'existant, nous avons validé le périmètre du projet, identifié la parcours utilisateur, validé les fonctionnalités prioritaires et réalisé une analyse d'architecture pour comprendre la gestion des échanges et du stockage de données.

Nous avons ensuité réalisé une grille d’évaluation des outils selon différents critères : fonctionnels, techniques et responsables.

Cette démarche a abouti à la réalisation d'un prototype permettant à Equip'tout de valider le choix de l'ERP, ainsi que de créer de la confiance entre l'organisation retenue et Equip'tout.

## 4 critères pour choisir un ERP responsable

Au delà de l'objectif d'avoir un ERP adapté au métier d'Equip'tout et conforme au futur changement de réglementation, nous avions 4 objectifs complémentaires.

**Le service numérique est écoconçu** afin de réduire les impacts environnementaux :

* le service fonctionne sur des vieux ordinateurs ;
* les fonctionnalités sont utiles, utilisables et utilisées ;
* les bonnes pratiques d'écoconception sont respectées. Vérifiez s'ils ont fait : une analyse du cycle de vie (ACV), une analyse de la maturité des 115 bonnes pratiques d'écoconception web ou une estimation des impacts avec EcoIndex.

**L'ERP est accessible** à tous quelque soit son contexte d'utilisation :

* le service numérique a une interface simple et une navigation possible au clavier ;
* il possède une version web lisible par un lecteur d'écran ;
* une démarche d'évaluation et d'amélioration est en cours. Par exemple, ils ont fait : un audit RGAA, ils sont certifiés OPQUAST et/ou formé à l'accessibilité numérique.

**La logiciel est open source,** le service est accessible sans limite et le code est accessible, étudiable, modifiable et redistribuable :

* il n'y a pas de sur-coût de licence pour accéder à certaines fonctionnalités ;
* une communauté existe ;
* nous sommes libres de développer sur la plateforme avec n'importe quel partenaire.

**La solution est durable**, le service est modulable, il est possible de connecter / déconnecter des modules internes et externes au service :

* le langage utilisé pour s'assurer que les connaissances sont présentes localement ;
* la possibilité d'avoir une assistance et d'être formé à l'administration technique et métier ;
* le service est exploitable au travers d'API.

Cela n'a pas été le cas ici, mais il aurait été possible que certaines organisations soit labellisées, comme le Label Numérique Responsable, le label B Corp ou face référence à des reconnaissances comme WattImpact. Cela ne doit pas dispenser de questionner et de vérifier les véritables intentions des organisations.

## Nous avons choisi de travailler avec Tryton

Nous avons constaté que les ERPs répondent assez peu aux critères d'écoconception et d'accessibilité.

Cependant, notre choix s'est naturellement porté sur Tryton, pour plusieurs raisons :

* L'opportunité de concevoir de façon responsable le module de location non existant à date
* La possibilité de naviguer au clavier et d'ajuster l'interface pour répondre au geste métier
* L'absence de frais d'utilisation de l'ERP et la liberté de choisir les partenaires (véritablement open source)
* La possibilité d'utiliser le service sans être connectée au réseau internet


Cerdic Krier, manager chez B2CK qui est l'entreprise référente dans le déploiement de Tryton :
"Nous sommes ravis d'avoir été choisi pour faire les développements et les adaptations pour l'implémentation de
Tryton chez Equip'Tout. Cela va permetttre d'étendre les fonctionnalités de base de Tryton avec un nouveau module de gestion de location."

Si vous souhaitez [réduire l'empreinte environnementale et sociale de votre solution ](https://www.itsonus.fr/nos_services/reduire_impacts_numerique/)ou si vous souhaitez vous [former au numérique responsable](https://www.itsonus.fr/nos_services/formations/), pensez à nous [contacter](https://www.itsonus.fr/contact/).
